@@ -12,11 +12,10 @@ from shutil import copyfile
 
 from netifaces import interfaces, ifaddresses
 from ojota import set_data_source
-from pyaml import yaml
 from qtfaststart.processor import get_index
 from qtfaststart.exceptions import FastStartException
 
-
+from altasetting import Settings
 from touchandgo.settings import SKIP_MOOV
 
 
@@ -24,15 +23,16 @@ LOCKFILE = "/tmp/touchandgo"
 
 log = logging.getLogger('touchandgo.helpers')
 
+
 def get_settings():
     settings_file = "%s/.touchandgo/settings.yaml" % os.getenv("HOME")
+    default = join(dirname(__file__), "templates", "settings.yaml")
 
     set_config_dir()
     if not exists(settings_file):
-        default = join(dirname(__file__), "templates", "settings.yaml")
         copyfile(default, settings_file)
 
-    settings = yaml.load(open(settings_file).read())
+    settings = Settings(settings_file, default)
     return settings
 
 
